@@ -1,6 +1,6 @@
 /* BSD 3-Clause License
  *
- * Copyright © 2008-2019, Jice and the libtcod contributors.
+ * Copyright © 2008-2021, Jice and the libtcod contributors.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -29,6 +29,7 @@
  * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
  */
+// clang-format off
 #ifndef _TCOD_LIST_HPP
 #define _TCOD_LIST_HPP
 
@@ -45,7 +46,8 @@ Note that this module has no Python wrapper. Use Python built-in containers inst
  */
 
 // fast & lightweight list template
-template <class T> class TCODList {
+template <class T>
+class TCODList {
 	T *array;
 	int fillSize;
 	int allocSize;
@@ -66,6 +68,7 @@ public :
 		TCOD_list_t intList = TCOD_list_new();
 		TCOD_list_t floatList = TCOD_list_new();
 	*/
+  [[deprecated("TCODList is unsuitable as a C++ container.")]]
 	TCODList() {
 		array=NULL;
 		fillSize=allocSize=0;
@@ -94,7 +97,7 @@ public :
     array = NULL;
     fillSize = allocSize = 0;
     for (void** it = TCOD_list_begin(l); it != TCOD_list_end(l); ++it) {
-      push(*reinterpret_cast<T*>(it));
+      push(*static_cast<T*>(static_cast<void*>(it)));
     }
   }
 	TCODList(const TCODList<T> &l2) {
@@ -113,6 +116,7 @@ public :
 	@CppEx TCODList<int> intList(5); // create an empty list, pre-allocate memory for 5 elements
 	@CEx TCOD_list_t intList = TCOD_list_allocate(5);
 	*/
+  [[deprecated("TCODList is unsuitable as a C++ container.")]]
 	TCODList(int nbElements) {
 		fillSize=0;
 		allocSize=nbElements;
@@ -509,7 +513,7 @@ public :
 	@PageName list_iterator
 	@PageFather list
 	@PageTitle Iterators
-	@FuncDesc You can iterate through the elements of the list using an iterator. begin() returns the address of the first element of the list. You go to the next element using the increment operator ++. When the iterator's value is equal to end(), you've gone through all the elements. <b>Warning ! You cannot insert elements in the list while iterating through it. Inserting elements can result in reallocation of the list and your iterator will not longer be valid.</b>
+	@FuncDesc You can iterate through the elements of the list using an iterator. begin() returns the address of the first element of the list. You go to the next element using the increment operator ++. When the iterators value is equal to end(), you've gone through all the elements. <b>Warning ! You cannot insert elements in the list while iterating through it. Inserting elements can result in reallocation of the list and your iterator will not longer be valid.</b>
 	@Cpp
 		template <class T> T * TCODList::begin() const
 		template <class T> T * TCODList::end() const
