@@ -1,6 +1,6 @@
 /* BSD 3-Clause License
  *
- * Copyright © 2008-2019, Jice and the libtcod contributors.
+ * Copyright © 2008-2021, Jice and the libtcod contributors.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -29,6 +29,7 @@
  * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
  */
+// clang-format off
 #ifndef _TCOD_RANDOM_HPP
 #define _TCOD_RANDOM_HPP
 
@@ -151,6 +152,14 @@ class TCODLIB_API TCODRandom {
 		*/
 		TCODRandom(uint32_t seed, TCOD_random_algo_t algo = TCOD_RNG_CMWC);
 
+    /**
+        Take ownership of a `TCOD_Random*` pointer.
+        \rst
+        .. versionadded:: 1.16
+        \endrst
+     */
+    explicit TCODRandom(TCOD_Random*&& mersenne) : data(mersenne) {}
+
 		/**
 		@PageName random_init
 		@FuncTitle Destroying a RNG
@@ -203,7 +212,7 @@ Essentially, this is the same as TCOD_DISTRIBUTION_GAUSSIAN. The difference is t
 5. TCOD_DISTRIBUTION_GAUSSIAN_RANGE_INVERSE
 Essentially, this is the same as TCOD_DISTRIBUTION_GAUSSIAN_RANGE, but the min and max values have the greatest probability of appearing, while the values between them, the lowest.
 
-There exist functions to also specify both a min-max range AND a custom mean, which can be any value (possibly either min or max, but it can even be outside that range). In case such a function is used, the distributions will trigger a slihtly different behaviour:
+There exist functions to also specify both a min-max range AND a custom mean, which can be any value (possibly either min or max, but it can even be outside that range). In case such a function is used, the distributions will trigger a slightly different behaviour:
 * TCOD_DISTRIBUTION_LINEAR
 * TCOD_DISTRIBUTION_GAUSSIAN
 * TCOD_DISTRIBUTION_GAUSSIAN_RANGE
@@ -392,6 +401,20 @@ In these cases, the selected mean will appear with the lowest frequency.
 		inline int diceRoll (TCOD_dice_t dice) { return TCOD_random_dice_roll(data,dice); }
 		inline int diceRoll (const char * s) { return TCOD_random_dice_roll(data,TCOD_random_dice_new(s)); }
 
+    /**
+        Return this objects `TCOD_Random*` pointer.
+        \rst
+        .. versionadded:: 1.16
+        \endrst
+     */
+		TCOD_Random* get_data() noexcept
+		{
+			return data;
+		}
+		const TCOD_Random* get_data() const noexcept
+		{
+			return data;
+		}
 	protected :
 		friend class TCODLIB_API TCODNoise;
 		friend class TCODLIB_API TCODHeightMap;
