@@ -1,6 +1,6 @@
 /* BSD 3-Clause License
  *
- * Copyright © 2008-2019, Jice and the libtcod contributors.
+ * Copyright © 2008-2021, Jice and the libtcod contributors.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -29,6 +29,7 @@
  * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
  */
+// clang-format off
 #ifndef _TCOD_SYS_HPP
 #define _TCOD_SYS_HPP
 
@@ -116,7 +117,6 @@ public :
 	*/
 	static float getLastFrameLength();
 
-#ifdef TCOD_OSUTIL_SUPPORT
 	/**
 	@PageName system_time
 	@FuncTitle Pause the program
@@ -153,9 +153,7 @@ public :
 	@Lua tcod.system.getElapsedSeconds()
 	*/
 	static float getElapsedSeconds();
-#endif
 
-#ifdef TCOD_CONSOLE_SUPPORT
 	/**
 	@PageName console_blocking_input
 	@FuncTitle Waiting for any event (mouse or keyboard)
@@ -191,6 +189,7 @@ public :
 		TCOD_event_t ev = TCOD_sys_wait_for_event(TCOD_EVENT_ANY,&key,&mouse,true);
 		if ( ev == TCOD_EVENT_KEY_PRESS && key.c == 'i' ) { ... open inventory ... }
 	*/
+  [[deprecated("This API is deprecated, use SDL_WaitEvent instead.")]]
 	static TCOD_event_t waitForEvent(int eventMask, TCOD_key_t *key, TCOD_mouse_t *mouse, bool flush);
 
 	/**
@@ -225,10 +224,9 @@ public :
 		TCOD_event_t ev = TCOD_sys_check_for_event(TCOD_EVENT_ANY,&key,&mouse);
 		if ( ev == TCOD_EVENT_KEY_PRESS && key.c == 'i' ) { ... open inventory ... }
 	*/
+  [[deprecated("This API is deprecated, use SDL_PollEvent instead.")]]
 	static TCOD_event_t checkForEvent(int eventMask, TCOD_key_t *key, TCOD_mouse_t *mouse);
-#endif
 
-#ifndef TCOD_BARE
 	/**
 	@PageName system_screenshots
 	@PageFather system
@@ -242,7 +240,6 @@ public :
 	@Param filename Name of the file. If NULL, a filename is automatically generated with the form "./screenshotNNN.png", NNN being the first free number (if a file named screenshot000.png already exist, screenshot001.png will be used, and so on...).
 	*/
 	static void saveScreenshot(const char *filename);
-#endif
 
 	/**
 	@PageName system_filesystem
@@ -415,7 +412,6 @@ public :
 	@Param x,y,w,h Part of the root console you want to redraw even if nothing has changed in the console back/fore/char.
 	*/
 
-#ifndef TCOD_BARE
 	/**
 	@PageName system_misc
 	@PageFather system
@@ -462,12 +458,12 @@ public :
 	@PageName system_misc
 	@FuncTitle Get fullscreen offset
 	@FuncDesc If the fullscreen resolution does not matches the console size in pixels, black borders are added. This function returns the position in pixels of the console top left corner in the screen.
-	@Cpp static void TCODSystem::getFullscreenOffsets(int *offx, int *offy)
-	@C void TCOD_sys_get_fullscreen_offsets(int *offx, int *offy)
-	@C# static void TCODSystem::getFullscreenOffsets(out int offx, out int offy);
-	@Param offx,offy contains the position of the console on the screen when using fullscreen mode.
+	@Cpp static void TCODSystem::getFullscreenOffsets(int *offset_x, int *offset_y)
+	@C void TCOD_sys_get_fullscreen_offsets(int *offset_x, int *offset_y)
+	@C# static void TCODSystem::getFullscreenOffsets(out int offset_x, out int offset_y);
+	@Param offset_x,offset_y contains the position of the console on the screen when using fullscreen mode.
 	*/
-	static void getFullscreenOffsets(int *offx, int *offy);
+	static void getFullscreenOffsets(int *offset_x, int *offset_y);
 
 	/**
 	@PageName system_misc
@@ -485,18 +481,16 @@ public :
 	@PageName system_misc
 	@FuncTitle Dynamically updating the font bitmap
 	@FuncDesc You can dynamically change the bitmap of a character in the font. All cells using this ascii code will be updated at next flush call.
-	@Cpp static void TCODSystem::updateChar(int asciiCode, int fontx, int fonty,const TCODImage *img,int x,int y)
-	@C void TCOD_sys_update_char(int asciiCode, int fontx, int fonty, TCOD_image_t img, int x, int y)
-	@Py sys_update_char(asciiCode,fontx,fonty,img,x,y)
+	@Cpp static void TCODSystem::updateChar(int asciiCode, int font_x, int font_y,const TCODImage *img,int x,int y)
+	@C void TCOD_sys_update_char(int asciiCode, int font_x, int font_y, TCOD_image_t img, int x, int y)
+	@Py sys_update_char(asciiCode,font_x,font_y,img,x,y)
 	@Param asciiCode ascii code corresponding to the character to update
-	@Param fontx,fonty coordinate of the character in the bitmap font (in characters, not pixels)
+	@Param font_x,font_y coordinate of the character in the bitmap font (in characters, not pixels)
 	@Param img image containing the new character bitmap
 	@Param x,y position in pixels of the top-left corner of the character in the image
 	*/
-	static void updateChar(int asciiCode, int fontx, int fonty,const TCODImage *img,int x,int y);
-#endif
+	static void updateChar(int asciiCode, int font_x, int font_y,const TCODImage *img,int x,int y);
 
-#ifndef TCOD_BARE
 	/**
 	@PageName system_misc
 	@FuncTitle Dynamically change libtcod's internal renderer
@@ -548,7 +542,6 @@ public :
 	*/
   TCOD_DEPRECATED_NOMESSAGE
 	static char *getClipboard();
-#endif
 
 	// thread stuff
   TCOD_DEPRECATED_NOMESSAGE
